@@ -1,20 +1,19 @@
 /****************************************************************************/
+// Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
+/****************************************************************************/
+//
+//   This program and the accompanying materials
+//   are made available under the terms of the Eclipse Public License v2.0
+//   which accompanies this distribution, and is available at
+//   http://www.eclipse.org/legal/epl-v20.html
+//
+/****************************************************************************/
 /// @file    GNEDetectorEntry.cpp
 /// @author  Pablo Alvarez Lopez
 /// @date    Nov 2015
-/// @version $Id: GNEDetectorEntry.cpp 24016 2017-04-22 14:13:39Z palcraft $
+/// @version $Id$
 ///
-///
-/****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
-/****************************************************************************/
-//
-//   This file is part of SUMO.
-//   SUMO is free software; you can redistribute it and/or modify
-//   it under the terms of the GNU General Public License as published by
-//   the Free Software Foundation; either version 3 of the License, or
-//   (at your option) any later version.
 //
 /****************************************************************************/
 
@@ -30,7 +29,6 @@
 #include <string>
 #include <iostream>
 #include <utility>
-#include <foreign/polyfonts/polyfonts.h>
 #include <utils/geom/PositionVector.h>
 #include <utils/common/RandHelper.h>
 #include <utils/common/SUMOVehicleClass.h>
@@ -39,7 +37,6 @@
 #include <utils/gui/windows/GUISUMOAbstractView.h>
 #include <utils/gui/windows/GUIAppEnum.h>
 #include <utils/gui/images/GUITextureSubSys.h>
-#include <utils/gui/div/GUIParameterTableWindow.h>
 #include <utils/gui/globjects/GUIGLObjectPopupMenu.h>
 #include <utils/gui/div/GUIGlobalSelection.h>
 #include <utils/gui/div/GLHelper.h>
@@ -60,14 +57,8 @@
 // member method definitions
 // ===========================================================================
 
-GNEDetectorEntry::GNEDetectorEntry(GNEViewNet* viewNet, GNEDetectorE3* parent, GNELane* lane, double pos) :
-    GNEDetector(parent->generateEntryID(), viewNet, SUMO_TAG_DET_ENTRY, ICON_E3ENTRY, lane, pos, 0, ""),
-    myE3Parent(parent) {
-    // Update geometry
-    updateGeometryByParent();
-    // Set colors
-    myBaseColor = RGBColor(0, 204, 0, 255);
-    myBaseColorSelected = RGBColor(125, 204, 0, 255);
+GNEDetectorEntry::GNEDetectorEntry(GNEViewNet* viewNet, GNEDetectorE3* parent, GNELane* lane, double pos, bool friendlyPos) :
+    GNEDetector(parent->generateEntryID(), viewNet, SUMO_TAG_DET_ENTRY, ICON_E3ENTRY, lane, pos, 0, "", friendlyPos, parent) {
 }
 
 
@@ -76,12 +67,6 @@ GNEDetectorEntry::~GNEDetectorEntry() {}
 
 void
 GNEDetectorEntry::updateGeometry() {
-    myE3Parent->updateGeometry();
-}
-
-
-void
-GNEDetectorEntry::updateGeometryByParent() {
     // Clear all containers
     myShapeRotations.clear();
     myShapeLengths.clear();
@@ -89,40 +74,45 @@ GNEDetectorEntry::updateGeometryByParent() {
     // clear Shape
     myShape.clear();
 
-    // Get shape of lane parent
-    myShape.push_back(myLane->getShape().positionAtOffset(myLane->getPositionRelativeToParametricLength(myPosition.x())));
+    // obtain position over lane
+    double fixedPositionOverLane = myPositionOverLane > 1 ? 1 : myPositionOverLane < 0 ? 0 : myPositionOverLane;
+    myShape.push_back(myLane->getShape().positionAtOffset(fixedPositionOverLane * myLane->getShape().length()));
 
     // Save rotation (angle) of the vector constructed by points f and s
-    myShapeRotations.push_back(myLane->getShape().rotationDegreeAtOffset(myLane->getPositionRelativeToParametricLength(myPosition.x())) * -1);
+    myShapeRotations.push_back(myLane->getShape().rotationDegreeAtOffset(fixedPositionOverLane * myLane->getShape().length()) * -1);
 
     // Set block icon position
     myBlockIconPosition = myShape.getLineCenter();
 
-    // Set offset of logo
-    myDetectorLogoOffset = Position(-2, 0);
-
     // Set block icon rotation, and using their rotation for logo
     setBlockIconRotation(myLane);
 
     // Refresh element (neccesary to avoid grabbing problems)
-    myViewNet->getNet()->refreshAdditional(this);
-}
+    myViewNet->getNet()->refreshElement(this);
 
-Position
-GNEDetectorEntry::getPositionInView() const {
-    return myLane->getShape().positionAtOffset(myLane->getPositionRelativeToParametricLength(myPosition.x()));
-}
-
-
-GNEDetectorE3*
-GNEDetectorEntry::getE3Parent() const {
-    return myE3Parent;
+    // update E3 parent Geometry
+    myAdditionalParent->updateGeometry();
 }
 
 
 void
-GNEDetectorEntry::writeAdditional(OutputDevice&) const {
-    // This additional cannot be writted calling this function because is writted by their E3Parent
+GNEDetectorEntry::writeAdditional(OutputDevice& device) const {
+    device.openTag(getTag());
+    device.writeAttr(SUMO_ATTR_LANE, myLane->getID());
+    device.writeAttr(SUMO_ATTR_POSITION, getAbsolutePositionOverLane());
+    device.writeAttr(SUMO_ATTR_FRIENDLY_POS, myFriendlyPosition);
+    device.closeTag();
+}
+
+
+bool GNEDetectorEntry::isDetectorPositionFixed() const {
+    // with friendly position enabled position are "always fixed"
+    if (myFriendlyPosition) {
+        return true;
+    } else {
+        // floors are needed to avoid precision problems
+        return ((floor(myPositionOverLane * 1000) / 1000) >= 0) && ((floor(myPositionOverLane * 1000) / 1000) <= 1);
+    }
 }
 
 
@@ -137,20 +127,20 @@ GNEDetectorEntry::drawGL(const GUIVisualizationSettings& s) const {
 
     // Set initial values
     if (isAdditionalSelected()) {
-        glColor3d(myBaseColorSelected.red(), myBaseColorSelected.green(), myBaseColorSelected.blue());
+        GLHelper::setColor(myViewNet->getNet()->selectedAdditionalColor);
     } else {
-        glColor3d(myBaseColor.red(), myBaseColor.green(), myBaseColor.blue());
+        GLHelper::setColor(s.SUMO_color_E3Entry);
     }
     const double exaggeration = s.addSize.getExaggeration(s);
     glPolygonMode(GL_FRONT_AND_BACK, GL_FILL);
 
-    // Push poligon matrix
+    // Push polygon matrix
     glPushMatrix();
     glScaled(exaggeration, exaggeration, 1);
     glTranslated(myShape[0].x(), myShape[0].y(), 0);
     glRotated(myShapeRotations[0], 0, 0, 1);
 
-    // Draw poligon
+    // Draw polygon
     glBegin(GL_LINES);
     glVertex2d(1.7, 0);
     glVertex2d(-1.7, 0);
@@ -172,7 +162,7 @@ GNEDetectorEntry::drawGL(const GUIVisualizationSettings& s) const {
     GLHelper::drawBoxLine(Position(0, 4), 0, 2, .05);
     GLHelper::drawTriangleAtEnd(Position(0, 4), Position(0, 1), (double) 1, (double) .25);
 
-    // Pop poligon matrix
+    // Pop polygon matrix
     glPopMatrix();
 
     // Pop detector matrix
@@ -180,9 +170,32 @@ GNEDetectorEntry::drawGL(const GUIVisualizationSettings& s) const {
 
     // Check if the distance is enought to draw details
     if (s.scale * exaggeration >= 10) {
-        // Draw icon
-        drawDetectorIcon(GUITextureSubSys::getTexture(GNETEXTURE_ENTRY), 1.5, 1);
-
+        // Push matrix
+        glPushMatrix();
+        // Traslate to center of detector
+        glTranslated(myShape.getLineCenter().x(), myShape.getLineCenter().y(), getType() + 0.1);
+        // Rotate depending of myBlockIconRotation
+        glRotated(myBlockIconRotation, 0, 0, -1);
+        //move to logo position
+        glTranslated(1.9, 0, 0);
+        // draw Entry logo
+        if (isAdditionalSelected()) {
+            GLHelper::drawText("E3", Position(), .1, 2.8, myViewNet->getNet()->selectedAdditionalColor);
+        } else {
+            GLHelper::drawText("E3", Position(), .1, 2.8, RGBColor(0, 204, 0));
+        }
+        //move to logo position
+        glTranslated(1.7, 0, 0);
+        // Rotate depending of myBlockIconRotation
+        glRotated(90, 0, 0, 1);
+        // draw Entry text
+        if (isAdditionalSelected()) {
+            GLHelper::drawText("Entry", Position(), .1, 1, myViewNet->getNet()->selectedAdditionalColor);
+        } else {
+            GLHelper::drawText("Entry", Position(), .1, 1, RGBColor(0, 204, 0));
+        }
+        // pop matrix
+        glPopMatrix();
         // Show Lock icon depending of the Edit mode
         drawLockIcon(0.4);
     }
@@ -200,11 +213,15 @@ GNEDetectorEntry::getAttribute(SumoXMLAttr key) const {
         case SUMO_ATTR_ID:
             return getAdditionalID();
         case SUMO_ATTR_LANE:
-            return toString(myLane->getAttribute(SUMO_ATTR_ID));
+            return myLane->getID();
         case SUMO_ATTR_POSITION:
-            return toString(myPosition.x());
+            return toString(getAbsolutePositionOverLane());
+        case SUMO_ATTR_FRIENDLY_POS:
+            return toString(myFriendlyPosition);
         case GNE_ATTR_BLOCK_MOVEMENT:
             return toString(myBlocked);
+        case GNE_ATTR_PARENT:
+            return myAdditionalParent->getID();
         default:
             throw InvalidArgument(toString(getTag()) + " doesn't have an attribute of type '" + toString(key) + "'");
     }
@@ -220,9 +237,10 @@ GNEDetectorEntry::setAttribute(SumoXMLAttr key, const std::string& value, GNEUnd
         case SUMO_ATTR_ID:
         case SUMO_ATTR_LANE:
         case SUMO_ATTR_POSITION:
+        case SUMO_ATTR_FRIENDLY_POS:
         case GNE_ATTR_BLOCK_MOVEMENT:
+        case GNE_ATTR_PARENT:
             undoList->p_add(new GNEChange_Attribute(this, key, value));
-            updateGeometry();
             break;
         default:
             throw InvalidArgument(toString(getTag()) + " doesn't have an attribute of type '" + toString(key) + "'");
@@ -234,21 +252,17 @@ bool
 GNEDetectorEntry::isValid(SumoXMLAttr key, const std::string& value) {
     switch (key) {
         case SUMO_ATTR_ID:
-            if (myViewNet->getNet()->getAdditional(getTag(), value) == NULL) {
-                return true;
-            } else {
-                return false;
-            }
+            return isValidAdditionalID(value);
         case SUMO_ATTR_LANE:
-            if (myViewNet->getNet()->retrieveLane(value, false) != NULL) {
-                return true;
-            } else {
-                return false;
-            }
+            return (myViewNet->getNet()->retrieveLane(value, false) != NULL);
         case SUMO_ATTR_POSITION:
-            return (canParse<double>(value) && (parse<double>(value) >= 0) && (parse<double>(value) <= (myLane->getLaneParametricLength())));
+            return canParse<double>(value);
+        case SUMO_ATTR_FRIENDLY_POS:
+            return canParse<bool>(value);
         case GNE_ATTR_BLOCK_MOVEMENT:
             return canParse<bool>(value);
+        case GNE_ATTR_PARENT:
+            return (myViewNet->getNet()->getAdditional(SUMO_TAG_E3DETECTOR, value) != NULL);
         default:
             throw InvalidArgument(toString(getTag()) + " doesn't have an attribute of type '" + toString(key) + "'");
     }
@@ -258,23 +272,28 @@ void
 GNEDetectorEntry::setAttribute(SumoXMLAttr key, const std::string& value) {
     switch (key) {
         case SUMO_ATTR_ID:
-            setAdditionalID(value);
+            changeAdditionalID(value);
             break;
         case SUMO_ATTR_LANE:
-            changeLane(value);
+            myLane = changeLane(myLane, value);
             break;
         case SUMO_ATTR_POSITION:
-            myPosition = Position(parse<double>(value), 0);
-            updateGeometry();
-            getViewNet()->update();
+            myPositionOverLane = parse<double>(value) / myLane->getLaneParametricLength();
+            break;
+        case SUMO_ATTR_FRIENDLY_POS:
+            myFriendlyPosition = parse<bool>(value);
             break;
         case GNE_ATTR_BLOCK_MOVEMENT:
             myBlocked = parse<bool>(value);
-            getViewNet()->update();
+            break;
+        case GNE_ATTR_PARENT:
+            changeAdditionalParent(value);
             break;
         default:
             throw InvalidArgument(toString(getTag()) + " doesn't have an attribute of type '" + toString(key) + "'");
     }
+    // After setting attribute always update Geometry
+    updateGeometry();
 }
 
 /****************************************************************************/
