@@ -1,33 +1,40 @@
 #!/usr/bin/env python
-"""
-@file    netduplicate.py
-@author  Michael Behrisch
-@author  Jakob Erdmann
-@date    2013-04-01
-@version $Id: netduplicate.py 17235 2014-11-03 10:53:02Z behrisch $
+# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+# Copyright (C) 2013-2017 German Aerospace Center (DLR) and others.
+# This program and the accompanying materials
+# are made available under the terms of the Eclipse Public License v2.0
+# which accompanies this distribution, and is available at
+# http://www.eclipse.org/legal/epl-v20.html
 
+# @file    netduplicate.py
+# @author  Michael Behrisch
+# @author  Jakob Erdmann
+# @date    2013-04-01
+# @version $Id$
+
+"""
 Reads a sumo network and duplication descriptors (prefix:x-offset:y-offset)
 and creates a disconnected network of duplicates.
-
-SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-Copyright (C) 2013-2014 DLR (http://www.dlr.de/) and contributors
-
-This file is part of SUMO.
-SUMO is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 3 of the License, or
-(at your option) any later version.
 """
+from __future__ import absolute_import
+from __future__ import print_function
 
-import sys, os, subprocess, optparse, tempfile, shutil
+import sys
+import os
+import subprocess
+import optparse
+import tempfile
+import shutil
 sys.path.append(os.path.dirname(os.path.dirname(os.path.realpath(__file__))))
-import sumolib
+import sumolib  # noqa
+
 
 def parseArgs():
     USAGE = "Usage: " + sys.argv[0] + " <net> <prefix:x:y> <prefix:x:y>+"
     optParser = optparse.OptionParser(usage=USAGE)
     sumolib.pullOptions("netconvert", optParser)
-    optParser.add_option("--drop-types", action="store_true", default=False, help="Remove edge types")
+    optParser.add_option(
+        "--drop-types", action="store_true", default=False, help="Remove edge types")
     options, args = optParser.parse_args()
     if len(args) < 3:
         sys.exit(USAGE)
@@ -37,11 +44,11 @@ def parseArgs():
 
 
 def createPlain(netconvert, netfile, prefix, xOff, yOff):
-    subprocess.call([netconvert, 
-        "--sumo-net-file", netfile, 
-        "--offset.x", xOff, 
-        "--offset.y", yOff, 
-        "--plain-output-prefix", prefix])
+    subprocess.call([netconvert,
+                     "--sumo-net-file", netfile,
+                     "--offset.x", xOff,
+                     "--offset.y", yOff,
+                     "--plain-output-prefix", prefix])
 
 
 # run
@@ -54,12 +61,13 @@ def main():
     tlls = []
     tmpDir = tempfile.mkdtemp()
     for d in options.desc:
-        createPlain(netconvert, options.net, os.path.join(tmpDir, d[0]), d[1], d[2])
+        createPlain(
+            netconvert, options.net, os.path.join(tmpDir, d[0]), d[1], d[2])
         out = open(os.path.join(tmpDir, "%s_.nod.xml" % d[0]), 'w')
         for line in open(os.path.join(tmpDir, "%s.nod.xml" % d[0])):
             line = line.replace('id="', 'id="%s_' % d[0])
             line = line.replace('tl="', 'tl="%s_' % d[0])
-            out.write(line);
+            out.write(line)
         out.close()
         nodes.append(out.name)
         out = open(os.path.join(tmpDir, "%s_.edg.xml" % d[0]), 'w')
@@ -71,15 +79,15 @@ def main():
                 typeStart = line.find('type="')
                 if typeStart >= 0:
                     typeEnd = line.find('"', typeStart + 6)
-                    line = line[0:typeStart] + line[typeEnd+1:]
-            out.write(line);
+                    line = line[0:typeStart] + line[typeEnd + 1:]
+            out.write(line)
         out.close()
         edges.append(out.name)
         out = open(os.path.join(tmpDir, "%s_.con.xml" % d[0]), 'w')
         for line in open(os.path.join(tmpDir, "%s.con.xml" % d[0])):
             line = line.replace('from="', 'from="%s_' % d[0])
             line = line.replace('to="', 'to="%s_' % d[0])
-            out.write(line);
+            out.write(line)
         out.close()
         conns.append(out.name)
         out = open(os.path.join(tmpDir, "%s_.tll.xml" % d[0]), 'w')
@@ -88,7 +96,7 @@ def main():
             line = line.replace('from="', 'from="%s_' % d[0])
             line = line.replace('to="', 'to="%s_' % d[0])
             line = line.replace('tl="', 'tl="%s_' % d[0])
-            out.write(line);
+            out.write(line)
         out.close()
         tlls.append(out.name)
     options.node_files = ",".join(nodes)
@@ -96,7 +104,7 @@ def main():
     options.connection_files = ",".join(conns)
     options.tllogic_files = ",".join(tlls)
     if sumolib.call(netconvert, options) != 0:
-        print >> sys.stderr, "Something went wrong, check '%s'!" % tmpDir
+        print("Something went wrong, check '%s'!" % tmpDir, file=sys.stderr)
     else:
         shutil.rmtree(tmpDir)
 
