@@ -1,23 +1,18 @@
 #!/usr/bin/env python
-"""
-@file    randomTrips.py
-@author  Daniel Krajzewicz
-@author  Jakob Erdmann
-@author  Michael Behrisch
-@date    2010-03-06
-@version $Id: randomTrips.py 23999 2017-04-21 09:04:47Z behrisch $
+# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+# Copyright (C) 2010-2017 German Aerospace Center (DLR) and others.
+# This program and the accompanying materials
+# are made available under the terms of the Eclipse Public License v2.0
+# which accompanies this distribution, and is available at
+# http://www.eclipse.org/legal/epl-v20.html
 
-Generates random trips for the given network.
+# @file    randomTrips.py
+# @author  Daniel Krajzewicz
+# @author  Jakob Erdmann
+# @author  Michael Behrisch
+# @date    2010-03-06
+# @version $Id$
 
-SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-Copyright (C) 2010-2017 DLR (http://www.dlr.de/) and contributors
-
-This file is part of SUMO.
-SUMO is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 3 of the License, or
-(at your option) any later version.
-"""
 
 from __future__ import print_function
 from __future__ import absolute_import
@@ -25,7 +20,6 @@ import os
 import sys
 import random
 import bisect
-import datetime
 import subprocess
 from collections import defaultdict
 import math
@@ -34,7 +28,7 @@ import optparse
 SUMO_HOME = os.environ.get('SUMO_HOME',
                            os.path.join(os.path.dirname(os.path.abspath(__file__)), '..', '..'))
 sys.path.append(os.path.join(SUMO_HOME, 'tools'))
-import sumolib
+import sumolib  # noqa
 import route2trips
 from sumolib.miscutils import euclidean
 
@@ -63,6 +57,10 @@ def get_options(args=None):
                          default=False, help="create a person file with pedestrian trips instead of vehicle trips")
     optParser.add_option("--persontrips", action="store_true",
                          default=False, help="create a person file with person trips instead of vehicle trips")
+    optParser.add_option("--persontrip.transfer.car-walk", dest="carWalkMode", 
+            help="Where are mode changes from car to walking allowed (possible values: 'ptStops', 'allJunctions' and combinations)")
+    optParser.add_option("--persontrip.walkfactor", dest="walkfactor", 
+            help="Use FLOAT as a factor on pedestrian maximum speed during intermodal routing")
     optParser.add_option("--prefix", dest="tripprefix",
                          default="", help="prefix for the trip ids")
     optParser.add_option("-t", "--trip-attributes", dest="tripattrs",
@@ -189,9 +187,9 @@ class RandomTripGenerator:
             else:
                 destCoord = sink_edge.getToNode().getCoord()
 
-            coords = ([source_edge.getFromNode().getCoord()]
-                      + [e.getFromNode().getCoord() for e in intermediate]
-                      + [destCoord])
+            coords = ([source_edge.getFromNode().getCoord()] +
+                      [e.getFromNode().getCoord() for e in intermediate] +
+                      [destCoord])
             distance = sum([euclidean(p, q)
                             for p, q in zip(coords[:-1], coords[1:])])
             if distance >= min_distance and (max_distance is None or distance < max_distance):
@@ -214,11 +212,11 @@ def get_prob_fun(options, fringe_bonus, fringe_forbidden):
         if options.lanes:
             prob *= edge.getLaneNumber()
         prob *= (edge.getSpeed() ** options.speed_exponent)
-        if (options.fringe_factor != 1.0
-                and not options.pedestrians
-                and fringe_bonus is not None
-                and edge.getSpeed() > options.fringe_threshold
-                and edge.is_fringe(getattr(edge, fringe_bonus))):
+        if (options.fringe_factor != 1.0 and
+                not options.pedestrians and
+                fringe_bonus is not None and
+                edge.getSpeed() > options.fringe_threshold and
+                edge.is_fringe(getattr(edge, fringe_bonus))):
             prob *= options.fringe_factor
         return prob
     return edge_probability
@@ -274,7 +272,7 @@ def buildTripGenerator(net, options):
 
 
 def is_walk_attribute(attr):
-    for cand in ['departPos', 'arrivalPos', 'speed', 'duration', 'busStop']:
+    for cand in ['arrivalPos', 'speed=', 'duration=', 'busStop=']:
         if cand in attr:
             return True
     return False
@@ -287,17 +285,64 @@ def is_persontrip_attribute(attr):
     return False
 
 
-def split_trip_attributes(tripattrs):
-    # figure out which of the tripattrs belong to the <person> and which
-    # belong to the <walk> or <persontrip>
-    personattrs = []
-    otherattrs = []
+def is_person_attribute(attr):
+    for cand in ['departPos', 'type']:
+        if cand in attr:
+            return True
+    return False
+
+
+def is_vehicle_attribute(attr):
+    for cand in ['depart', 'arrival', 'line', 'Number', 'type']:
+        if cand in attr:
+            return True
+    return False
+
+
+def split_trip_attributes(tripattrs, pedestrians, hasType):
+    # handle attribute values with a space
+    # assume that no attribute value includes an '=' sign
+    allattrs = []
     for a in tripattrs.split():
-        if is_walk_attribute(a) or is_persontrip_attribute(a):
-            otherattrs.append(a)
+        if "=" in a:
+            allattrs.append(a)
         else:
-            personattrs.append(a)
-    return prependSpace(' '.join(personattrs)), prependSpace(' '.join(otherattrs))
+            if len(allattrs) == 0:
+                print("Warning: invalid trip-attribute '%s'" % a)
+            else:
+                allattrs[-1] += ' ' + a
+
+    # figure out which of the tripattrs belong to the <person> or <vehicle>,
+    # which belong to the <vType> and which belong to the <walk> or <persontrip>
+    vehicleattrs = []
+    personattrs = []
+    vtypeattrs = []
+    otherattrs = []
+    for a in allattrs:
+        if pedestrians:
+            if is_walk_attribute(a) or is_persontrip_attribute(a):
+                otherattrs.append(a)
+            elif is_person_attribute(a):
+                personattrs.append(a)
+            else:
+                vtypeattrs.append(a)
+        else:
+            if is_vehicle_attribute(a):
+                vehicleattrs.append(a)
+            else:
+                vtypeattrs.append(a)
+
+    if not hasType:
+        if pedestrians:
+            personattrs += vtypeattrs
+        else:
+            vehicleattrs += vtypeattrs
+        vtypeattrs = []
+
+    return (prependSpace(' '.join(vtypeattrs)),
+            prependSpace(' '.join(vehicleattrs)),
+            prependSpace(' '.join(personattrs)),
+            prependSpace(' '.join(otherattrs)))
 
 
 def prependSpace(s):
@@ -321,9 +366,8 @@ def main(options):
     trip_generator = buildTripGenerator(net, options)
     idx = 0
 
-    if options.pedestrians:
-        personattrs, otherattrs = split_trip_attributes(options.tripattrs)
-    options.tripattrs = prependSpace(options.tripattrs)
+    vtypeattrs, options.tripattrs, personattrs, otherattrs = split_trip_attributes(
+        options.tripattrs, options.pedestrians, options.vehicle_class)
 
     vias = {}
 
@@ -365,10 +409,10 @@ def main(options):
 
     with open(options.tripfile, 'w') as fouttrips:
         sumolib.writeXMLHeader(
-            fouttrips, "$Id: randomTrips.py 23999 2017-04-21 09:04:47Z behrisch $", "routes")
+            fouttrips, "$Id$", "routes")
         if options.vehicle_class:
-            fouttrips.write('    <vType id="%s" vClass="%s" />\n' %
-                            (options.vehicle_class, options.vehicle_class))
+            fouttrips.write('    <vType id="%s" vClass="%s"%s/>\n' %
+                            (options.vehicle_class, options.vehicle_class, vtypeattrs))
             options.tripattrs += ' type="%s"' % options.vehicle_class
         depart = options.begin
         if trip_generator:
@@ -379,7 +423,7 @@ def main(options):
                         idx = generate_one(idx)
                         depart += options.period
                     else:
-                        # draw n times from a bernouli distribution
+                        # draw n times from a Bernoulli distribution
                         # for an average arrival rate of 1 / period
                         prob = 1.0 / options.period / options.binomial
                         for i in range(options.binomial):
@@ -393,10 +437,14 @@ def main(options):
         fouttrips.write("</routes>\n")
 
     if options.routefile:
-        args = [DUAROUTER, '-n', options.netfile, '-t', options.tripfile, '-o', options.routefile, '--ignore-errors',
+        args = [DUAROUTER, '-n', options.netfile, '-r', options.tripfile, '-o', options.routefile, '--ignore-errors',
                 '--begin', str(options.begin), '--end', str(options.end), '--no-step-log', '--no-warnings']
         if options.additional is not None:
             args += ['--additional-files', options.additional]
+        if options.carWalkMode is not None:
+            args += ['--persontrip.transfer.car-walk', options.carWalkMode]
+        if options.walkfactor is not None:
+            args += ['--persontrip.walkfactor', options.walkfactor]
         print("calling ", " ".join(args))
         subprocess.call(args)
 
@@ -413,7 +461,7 @@ def main(options):
         trip_generator.via_generator.write_weights(
             options.weights_outprefix + VIA_SUFFIX)
 
-    # return wether trips could be genreated as requested
+    # return wether trips could be generated as requested
     return trip_generator is not None
 
 if __name__ == "__main__":
